Game

Struct Game 

pub struct Game {
    pub taking_all: [u64; 4],
    pub taking: Vec<u8>,
    pub breaking: Vec<u8>,
}

Fields

taking_all: [u64; 4]taking: Vec<u8>breaking: Vec<u8>

Implementations

Source

impl Game

pub fn from_ascii(s: &[u8]) -> Option<Game>

pub fn can_take_all(&self, n: usize) -> bool

pub fn breaking_moves( &self, n: usize, ) -> BreakingMoveIterator<Copied<Iter<'_, u8>>>

pub fn rules(&self) -> [u8; 256]

Returns rules as a sequence of octal numbers.

pub fn to_ascii(&self, separator: u8) -> Vec<u8>

Returns rules as an ascii string, using given decimal separator (for example b'.').

pub fn taking_iters(&self, position: usize) -> usize

Returns the total number of taking iterations needed (by any of the methods: naive, RC or RC2) to calculate the nimbers of all positions up to and including the one given.

pub fn breaking_naive_iters(&self, position: usize) -> usize

Returns the total number of breaking iterations needed by the naive method to calculate the nimbers of all positions up to and including the one specified.

pub fn naive_iters(&self, position: usize) -> usize

Returns the total number of iterations needed by the naive method to calculate the nimbers of all positions up to and including the one specified.

pub fn period(&self, nimbers: &[u16]) -> Option<(usize, usize)>

Tries to calculates (pre-period, period) of the game using the nimbers of its few first positions.

Uses a generalized version of a theorem from the paper: Richard K. Guy and Cedric A. B. Smith, The G-values of various games, 1956